@@ -215,28 +215,24 @@ class ML():
                 'RSCV'  : {}
                 }},
         'RVMrbf'        : {
-            'estimator' : RVC(kernel='rbf'),
+            'estimator' : RVC(kernel='rbf', n_iter=1000, threshold_alpha=1e9),
             'parameters': {
-                'GSCV'  : { 'n_iter': [100, 300, 500, 1000, 2000, 3000, 5000],
-                            'tol': [ 1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2, 1e-1 ],
-                            'alpha': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
-                            'threshold_alpha': [1e2, 1e3, 1e5, 1e7, 1e8, 1e9],
-                            'beta': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
-                            'beta_fixed': [False, True],
-                            'bias_used': [False, True]
+                'GSCV'  : { 'tol': [ 1e-5, 1e-4, 1e-3, 1e-2, 1e-1 ],
+                            'alpha': [ 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'beta': [ 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'beta_fixed': [False],
+                            'bias_used': [True],
                           },
                 'RSCV'  : {}
                 }},
         'RVMpoly'        : {
-            'estimator' : RVC(kernel='poly'),
+            'estimator' : RVC(kernel='poly', n_iter=1000, threshold_alpha=1e9),
             'parameters': {
-                'GSCV'  : { 'n_iter': [100, 300, 500, 1000, 2000, 3000, 5000],
-                            'tol': [ 1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2, 1e-1 ],
-                            'alpha': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
-                            'threshold_alpha': [1e2, 1e3, 1e5, 1e7, 1e8, 1e9],
-                            'beta': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
-                            'beta_fixed': [False, True],
-                            'bias_used': [False, True]
+                'GSCV'  : { 'tol': [ 1e-5, 1e-4, 1e-3, 1e-2, 1e-1 ],
+                            'alpha': [ 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'beta': [ 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'beta_fixed': [False],
+                            'bias_used': [True]
                           },
                 'RSCV'  : {}
                 }},
