@@ -380,8 +380,11 @@ class MergeAllResult():
         All_Pred = MergeAllResult.revisedPred(All_Prob_median, All_Pred)
         ALL_Result  = pd.concat([All_Pred, All_Prob_mean, All_Prob_median, All_Prob_mad], axis=1)
         ALL_Resultv = ALL_Result[~ ALL_Result['TRUE'].isna()]
-        EvalueA = HyperparamOptimal.GetScore(ALL_Resultv.filter(regex='^TRUE|_mean$', axis=1), label=label)
-        self.log.CIF("The final mean evaluation: \n%s" % EvalueA)
+        if ALL_Resultv.shape[0] > 2:
+            EvalueA = HyperparamOptimal.GetScore(ALL_Resultv.filter(regex='^TRUE|_mean$', axis=1), label=label)
+            self.log.CIF("The final mean evaluation: \n%s" % EvalueA)
+        else:
+            EvalueA = pd.DataFrame([])
         self.log.CIF(('Finish %s'% label).center(45, '-'))
         self.allTest = allTest
         self.ALL_Result = ALL_Result
@@ -398,6 +401,8 @@ class MergeAllResult():
                 All_import['%s_median'%i]= All_import[i].median(axis=1)
             All_import.sort_values(by=['%s_mean'%i for i in column], ascending=[False]*len(column), inplace=True, axis=0)
             self.All_import = All_import
+        else:
+            self.All_import = pd.DataFrame([])
     
     def ModelScore(self, All_evluat):
         if All_evluat:
